@@ -92,5 +92,14 @@ class SummaryEmpty(MyBaseError):
 class DBError(KeyError):
     pass
 
+
+class DBConnectionError(TypeError):
+    pass
+
+
+class SuffixError(KeyError):
+    pass
+
+
 class StatementNonSupportError(MyBaseError):
     pass
